@@ -1,6 +1,6 @@
 package WWW::Domain::Registry::Joker;
 
-# $CNsys: lib/WWW/Domain/Registry/Joker.pm 2525 2008-11-14 11:20:58Z roam $
+# $CNsys: lib/WWW/Domain/Registry/Joker.pm 3201 2009-06-26 08:58:10Z roam $
 
 use 5.006;
 use strict;
@@ -15,7 +15,7 @@ use WWW::Domain::Registry::Joker::Response;
 
 our @ISA = qw(WWW::Domain::Registry::Joker::Loggish);
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =head1 NAME
 
@@ -250,9 +250,11 @@ parameters in the C<PARAMS> hash.  The request name string and
 the parameters (required and optional) are as specified by
 the DMAPI documentation
 
-Note that if a parameter is supplied with the empty string as a value,
-the C<do_request()> method will send the I<"!@!"> string instead,
-since the DMAPI considers empty values to mean no change requested.
+Note that for object modification requests (those which type is
+C<domain-owner-change> or ends in C<-modify>) if a parameter is supplied
+with the empty string as a value, the C<do_request()> method will send
+the I<"!@!"> string instead, since the DMAPI considers empty values to mean
+no change requested.
 
 Invokes the C<login()> method if necessary.
 
@@ -270,7 +272,8 @@ sub do_request($ $ %)
 	foreach (keys %data) {
 		if (defined($data{$_}) && length($data{$_})) {
 			$d{$_} = $data{$_};
-		} else {
+		} elsif ($type eq 'domain-owner-change' ||
+		    $type =~ /-modify$/) {
 			$d{$_} = '!@!';
 		}
 	}
@@ -410,7 +413,7 @@ Peter Pentchev, E<lt>roam@ringlet.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007, 2008 by Peter Pentchev
+Copyright (C) 2007 - 2009 by Peter Pentchev
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
